@@ -1,5 +1,5 @@
 /*
-  Copyright 1997-2022 Sam Lantinga
+  Copyright 1997-2024 Sam Lantinga
   Copyright 2022 Collabora Ltd.
 
   This software is provided 'as-is', without any express or implied
@@ -303,7 +303,11 @@ static const Format formats[] =
 #else
         SDL_FALSE,
 #endif
-        SDL_IMAGE_SAVE_PNG,
+#ifdef SDL_IMAGE_SAVE_PNG
+        SDL_IMAGE_SAVE_PNG ? SDL_TRUE : SDL_FALSE,
+#else
+        SDL_FALSE,
+#endif
         IMG_isPNG,
         IMG_LoadPNG_RW,
     },
